@@ -364,9 +364,9 @@ class EntryPointMixin:
             return self.gid[1]
 
 
-class ColoMixin:
+class ExtendsMixin:
     def get_vshard(self) -> int:
-        assert self.gid is not None, "Gid must be specified with colo-ed vertex."
+        assert self.gid is not None, "Gid must be specified for extended vertex."
         return self.gid[1]
 
 
@@ -427,7 +427,7 @@ class ShardMapper:
     def id_chooser(self, query, ident: List[Tuple[int, int]]) -> Set[str]:
         """
         Called when looking up entity by relationship.
-        - v.colo
+        - v.extends
         """
         logger.debug("id_chooser: query=%r ident=%r", query, ident)
         assert len(ident) == 1, (len(ident), ident)
